========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/manila.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

======
MANILA
======

You have come across an OpenStack shared file system service.  It has
identified itself as "Manila."  It was abstracted from the Cinder
project.

* Wiki: https://wiki.openstack.org/wiki/Manila
* Developer docs: https://docs.openstack.org/manila/latest/

Getting Started
---------------

If you'd like to run from the master branch, you can clone the git repo:

    git clone https://opendev.org/openstack/manila

For developer information please see
`HACKING.rst <https://opendev.org/openstack/manila/src/branch/master/HACKING.rst>`_

You can raise bugs here https://bugs.launchpad.net/manila

Python client
-------------

https://opendev.org/openstack/python-manilaclient

* Documentation for the project can be found at:

https://docs.openstack.org/manila/latest/

* Release notes for the project can be found at:

https://docs.openstack.org/releasenotes/manila/

* Source for the project:

https://opendev.org/openstack/manila

* Bugs:

https://bugs.launchpad.net/manila

* Blueprints:

https://blueprints.launchpad.net/manila

* Design specifications are tracked at:

https://specs.openstack.org/openstack/manila-specs/
